@@ -58,6 +58,7 @@ Preferences :: Preferences ()
   show_headers      = false;
   del_duplicates    = false;
   ret_status        = false;
+  _ignore_time_stamp= false;
   high_score        = 100;
   time_out_val      = 30;
   negative_allows   = 0;
@@ -82,8 +83,8 @@ Preferences& Preferences :: Instance ()
 
 void Preferences :: init (void)
 {
-  ((Size_score)(Preferences :: size_score)).score = 0;
-  ((Size_score)(Preferences :: size_score)).size  = 0;
+  size_score.score = 0;
+  size_score.size = 0;
 }
   
 void Preferences :: kill (void)
@@ -92,7 +93,17 @@ void Preferences :: kill (void)
   while (die_account != (Preferences :: accnts).end ())
     { die_account->clear (); die_account++; }
 }
-  
+
+void Preferences :: set_ignore_time_stamp(bool new_ts)
+{
+  _ignore_time_stamp = new_ts;
+}
+
+bool Preferences :: ignore_time_stamp()
+{
+  return _ignore_time_stamp;
+}
+
 // This function tries to locate a preferences file and, upon success,
 // stores the file path in prefs_file.  However, no data is loaded by
 // the open() function.
@@ -140,8 +151,8 @@ bool Preferences :: load (void)
   
   try
     {
-      RCParser rcparser (&prefs_stream);
-      rcparser.parse ((void*)NULL);
+      RCParser rcparser(&prefs_stream);
+      rcparser.parse();
     }
   catch (...) { throw; }
   
@@ -232,13 +243,13 @@ void Preferences :: set_headers_file (const char* name)
 {
   // Expand the given file name.
   wordexp_t result;
-  if (wordexp (name, &result, 0) == 0)
+  if (wordexp (name, &result, 0) == 0 && result.we_wordc > 0) {
     headers_file_name = result.we_wordv[0];
-  else
-    {
-      ERROR_MSG("Invalid file name: " + (string)name + ".");
-      exit (-1);
-    }
+  }
+  else {
+    ERROR_MSG("Invalid headers store-file name: `" + (string)name + "'.");
+    exit(-1);
+  }
   wordfree (&result);
 }
 
@@ -255,18 +266,17 @@ void Preferences :: set_log_file (const char* name)
 {
   // Only expand logfile name if none was already specified, eg on the
   // command line.
-  if (log_file_name.length () == 0)
-    {
-      wordexp_t result;
-      if (wordexp (name, &result, 0) == 0)
-	log_file_name = result.we_wordv[0];
-      else
-	{
-	  ERROR_MSG("Invalid file name: " + (string)name + ".");
-	  exit (-1);
-	}
-      wordfree (&result);
+  if (log_file_name.length() == 0) {
+    wordexp_t result;
+    if (wordexp(name, &result, 0) == 0 && result.we_wordc > 0) {
+      log_file_name = result.we_wordv[0];
     }
+    else {
+      ERROR_MSG("Invalid logfile name: `" + (string)name + "'.");
+      exit(-1);
+    }
+    wordfree (&result);
+  }
 }
 
 string Preferences :: log_file (void)
